@@ -26,7 +26,7 @@ class MainTest: public QObject
 
 private slots:
     void testMetaObject();
-    void testWorldCopy();
+    //void testWorldCopy();
     void testCollisionDetection();
     void testCollisionDetection_data();
 };
